@@ -1,7 +1,8 @@
 #' Correlation Analysis
 #'
 #' Performs a correlation analysis.
-#' You can easily visualize the result using [`plot()`][visualisation_recipe.easycormatrix()] (see examples [**here**](https://easystats.github.io/correlation/reference/visualisation_recipe.easycormatrix.html#ref-examples)).
+#' You can easily visualize the result using [`plot()`][visualisation_recipe.easycormatrix()]
+#' (see examples [**here**](https://easystats.github.io/correlation/reference/visualisation_recipe.easycormatrix.html#ref-examples)).
 #'
 #' @param data A data frame.
 #' @param data2 An optional data frame. If specified, all pair-wise correlations
@@ -148,16 +149,18 @@
 #' the variable to be adjusted for is a factor and is included as a random
 #' effect in a mixed model (note that the remaining continuous variables of the
 #' dataset will still be included as fixed effects, similarly to regular partial
-#' correlations). That said, there is an important difference between using
-#' `cor_test()` and `correlation()`: If you set `multilevel=TRUE` in
-#' `correlation()` but `partial` is set to `FALSE` (as per default), then a
-#' back-transformation from partial to non-partial correlation will be attempted
-#' (through [`pcor_to_cor()`][pcor_to_cor]). However, this is not possible when
-#' using `cor_test()` so that if you set `multilevel=TRUE` in it, the resulting
-#' correlations are partial one. Note that for Bayesian multilevel correlations,
-#' if `partial = FALSE`, the back transformation will also recompute *p*-values
-#' based on the new *r* scores, and will drop the Bayes factors (as they are not
-#' relevant anymore). To keep Bayesian scores, set `partial = TRUE`.
+#' correlations). The model is a random intercept model, i.e. the multilevel
+#' correlation is adjusted for `(1 | groupfactor)`.That said, there is an
+#' important difference between using `cor_test()` and `correlation()`: If you
+#' set `multilevel=TRUE` in `correlation()` but `partial` is set to `FALSE` (as
+#' per default), then a back-transformation from partial to non-partial
+#' correlation will be attempted (through [`pcor_to_cor()`][pcor_to_cor]).
+#' However, this is not possible when using `cor_test()` so that if you set
+#' `multilevel=TRUE` in it, the resulting correlations are partial one. Note
+#' that for Bayesian multilevel correlations, if `partial = FALSE`, the back
+#' transformation will also recompute *p*-values based on the new *r* scores,
+#' and will drop the Bayes factors (as they are not relevant anymore). To keep
+#' Bayesian scores, set `partial = TRUE`.
 #' }
 #'
 #' \subsection{Notes}{
@@ -177,9 +180,11 @@
 #' `stats` package are supported.
 #' }
 #'
-#' @examples
+#' @examplesIf requireNamespace("poorman", quietly = TRUE) && requireNamespace("psych", quietly = TRUE)
 #'
 #' library(correlation)
+#' library(poorman)
+#'
 #' results <- correlation(iris)
 #'
 #' results
@@ -187,24 +192,22 @@
 #' summary(results, redundant = TRUE)
 #'
 #' # pipe-friendly usage with  grouped dataframes from {dplyr} package
-#' if (require("poorman")) {
-#'   iris %>%
-#'     correlation(select = "Petal.Width", select2 = "Sepal.Length")
+#' iris %>%
+#'   correlation(select = "Petal.Width", select2 = "Sepal.Length")
 #'
-#'   # Grouped dataframe
-#'   # grouped correlations
-#'   iris %>%
-#'     group_by(Species) %>%
-#'     correlation()
+#' # Grouped dataframe
+#' # grouped correlations
+#' iris %>%
+#'   group_by(Species) %>%
+#'   correlation()
 #'
-#'   # selecting specific variables for correlation
-#'   mtcars %>%
-#'     group_by(am) %>%
-#'     correlation(
-#'       select = c("cyl", "wt"),
-#'       select2 = c("hp")
-#'     )
-#' }
+#' # selecting specific variables for correlation
+#' mtcars %>%
+#'   group_by(am) %>%
+#'   correlation(
+#'     select = c("cyl", "wt"),
+#'     select2 = c("hp")
+#'   )
 #'
 #' # supplying custom variable names
 #' correlation(anscombe, select = c("x1", "x2"), rename = c("var1", "var2"))
@@ -264,7 +267,7 @@ correlation <- function(data,
                         standardize_names = getOption("easystats.standardize_names", FALSE),
                         ...) {
   # valid matrix checks
-  if (partial == FALSE & multilevel) {
+  if (!partial && multilevel) {
     partial <- TRUE
     convert_back_to_r <- TRUE
   } else {
@@ -272,7 +275,7 @@ correlation <- function(data,
   }
 
   # p-adjustment
-  if (bayesian == TRUE) {
+  if (bayesian) {
     p_adjust <- "none"
   }
 
@@ -286,7 +289,9 @@ correlation <- function(data,
     all_selected <- c(select, select2)
     not_in_data <- !all_selected %in% colnames(data)
     if (any(not_in_data)) {
-      stop(paste0("Following variables are not in the data: ", all_selected[not_in_data], collapse = ", "))
+      insight::format_error(
+        paste0("Following variables are not in the data: ", all_selected[not_in_data], collapse = ", ")
+      )
     }
 
     # for grouped df, add group variables to both data frames
@@ -310,7 +315,7 @@ correlation <- function(data,
   # renaming the columns if so desired
   if (!is.null(rename)) {
     if (length(data) != length(rename)) {
-      warning("Mismatch between number of variables and names.")
+      insight::format_warning("Mismatch between number of variables and names.")
     } else {
       colnames(data) <- rename
     }
@@ -456,7 +461,7 @@ correlation <- function(data,
           modelframe <- rbind(modelframe, modelframe_current)
         }
       } else {
-        stop("'data2' should have the same grouping characteristics as data.")
+        stop("'data2' should have the same grouping characteristics as data.", call. = FALSE)
       }
     }
     # else
@@ -520,9 +525,9 @@ correlation <- function(data,
     data <- cbind(data, data2)
   }
 
-  if (ncol(data) <= 2 & any(sapply(data, is.factor)) & include_factors == FALSE) {
+  if (ncol(data) <= 2L && any(sapply(data, is.factor)) && !include_factors) {
     if (isTRUE(verbose)) {
-      warning("It seems like there is not enough continuous variables in your data. Maybe you want to include the factors? We're setting `include_factors=TRUE` for you.", call. = FALSE)
+      insight::format_warning("It seems like there is not enough continuous variables in your data. Maybe you want to include the factors? We're setting `include_factors=TRUE` for you.")
     }
     include_factors <- TRUE
   }
@@ -550,7 +555,7 @@ correlation <- function(data,
 
   # LOOP ----------------
 
-  for (i in 1:nrow(combinations)) {
+  for (i in seq_len(nrow(combinations))) {
     x <- as.character(combinations[i, "Parameter1"])
     y <- as.character(combinations[i, "Parameter2"])
 
@@ -582,13 +587,13 @@ correlation <- function(data,
       params <- result
     } else {
       if (!all(names(result) %in% names(params))) {
-        if ("r" %in% names(params) & !"r" %in% names(result)) {
+        if ("r" %in% names(params) && !"r" %in% names(result)) {
           names(result)[names(result) %in% c("rho", "tau")] <- "r"
         }
-        if ("r" %in% names(result) & !"r" %in% names(params)) {
+        if ("r" %in% names(result) && !"r" %in% names(params)) {
           names(params)[names(params) %in% c("rho", "tau")] <- "r"
         }
-        if (!"r" %in% names(params) & any(c("rho", "tau") %in% names(result))) {
+        if (!"r" %in% names(params) && any(c("rho", "tau") %in% names(result))) {
           names(params)[names(params) %in% c("rho", "tau")] <- "r"
           names(result)[names(result) %in% c("rho", "tau")] <- "r"
         }
