@@ -8,7 +8,7 @@ format.easycorrelation <- function(x,
                                    format = NULL,
                                    ...) {
   if (nrow(x) == 0) {
-    warning("The table is empty, no rows left to print.")
+    warning("The table is empty, no rows left to print.", call. = FALSE)
     return(as.data.frame(x))
   }
 
@@ -65,7 +65,7 @@ format.easycormatrix <- function(x,
 
   # Deduct if stars only
   stars_only <- FALSE
-  if (include_significance == FALSE && stars == TRUE) {
+  if (!include_significance && stars) {
     stars_only <- TRUE
   }
 
@@ -104,7 +104,7 @@ format.easycormatrix <- function(x,
       )
     }
 
-    if (stars_only == FALSE) {
+    if (!stars_only) {
       sig[, nums] <- sapply(sig[, nums], function(x) ifelse(x != "", paste0(" (", x, ")"), ""))
     }
 
@@ -115,6 +115,14 @@ format.easycormatrix <- function(x,
 
   # Prepare output
   out <- as.data.frame(x)
+
+  # remove redundant diagonal
+  if (isTRUE(attri$redundant)) {
+    for (i in colnames(out)) {
+      out[[i]][out$Parameter == i] <- ""
+    }
+  }
+
   attr(out, "table_footer") <- .format_easycorrelation_footer(x, format = format)
   attr(out, "table_caption") <- .format_easycorrelation_caption(x, format = format)
   out
@@ -142,9 +150,12 @@ format.easycormatrix <- function(x,
     } else {
       nobs <- paste0(min(x$n_Obs), "-", max(x$n_Obs))
     }
-    footer <- paste0(footer, "\nObservations: ", nobs, "\n")
+    footer <- paste0(footer, "\nObservations: ", nobs)
   }
 
+  # final new line
+  footer <- paste0(footer, "\n")
+
   # for html/markdown, create list
   if (!is.null(format) && format != "text") {
     footer <- unlist(strsplit(footer, "\n"))
