@@ -1,5 +1,6 @@
-
 test_that("cor_test frequentist", {
+  skip_if_not_or_load_if_installed("ggplot2")
+
   expect_error(cor_test(ggplot2::msleep, brainwt, sleep_rem))
 
   out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem")
@@ -7,6 +8,8 @@ test_that("cor_test frequentist", {
 })
 
 test_that("cor_test kendall", {
+  skip_if_not_or_load_if_installed("ggplot2")
+
   out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "kendall")
   out2 <- stats::cor.test(ggplot2::msleep$brainwt, ggplot2::msleep$sleep_rem, method = "kendall")
 
@@ -15,17 +18,17 @@ test_that("cor_test kendall", {
 })
 
 test_that("cor_test bayesian", {
-  if (require("BayesFactor", quietly = TRUE)) {
-    set.seed(123)
-    out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", bayesian = TRUE)
-    expect_equal(out$r, -0.1947696, tolerance = 0.01)
-  }
+  skip_if_not_or_load_if_installed("BayesFactor")
+
+  set.seed(123)
+  out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", bayesian = TRUE)
+  expect_equal(out$r, -0.1947696, tolerance = 0.01)
 })
 
 test_that("cor_test tetrachoric", {
-  skip_if_not_installed("psych")
-  skip_if_not_installed("polycor")
-  skip_if_not_installed("ggplot2")
+  skip_if_not_or_load_if_installed("psych")
+  skip_if_not_or_load_if_installed("polycor")
+  skip_if_not_or_load_if_installed("ggplot2")
 
   data <- ggplot2::msleep
   data$brainwt_binary <- ifelse(data$brainwt > 3, 1, 0)
@@ -48,7 +51,7 @@ test_that("cor_test tetrachoric", {
 
 
 test_that("cor_test robust", {
-  skip_if_not_installed("ggplot2")
+  skip_if_not_or_load_if_installed("ggplot2")
 
   out1 <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "pearson", ranktransform = TRUE)
   out2 <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "spearman", ranktransform = FALSE)
@@ -57,9 +60,9 @@ test_that("cor_test robust", {
 
 
 test_that("cor_test distance", {
-  skip_if_not_installed("ggplot2")
-  skip_if_not_installed("energy")
-  skip_if_not_installed("poorman")
+  skip_if_not_or_load_if_installed("ggplot2")
+  skip_if_not_or_load_if_installed("energy")
+  skip_if_not_or_load_if_installed("poorman")
 
   out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "distance")
   df <- poorman::filter(ggplot2::msleep, !is.na(brainwt), !is.na(sleep_rem))
@@ -69,8 +72,8 @@ test_that("cor_test distance", {
 
 
 test_that("cor_test percentage", {
-  skip_if_not_installed("ggplot2")
-  skip_if_not_installed("WRS2")
+  skip_if_not_or_load_if_installed("ggplot2")
+  skip_if_not_or_load_if_installed("WRS2")
 
   out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "percentage")
   comparison <- WRS2::pbcor(ggplot2::msleep$brainwt, ggplot2::msleep$sleep_rem)
@@ -79,42 +82,47 @@ test_that("cor_test percentage", {
 
 
 test_that("cor_test shepherd", {
+  skip_if_not_or_load_if_installed("ggplot2")
+
   set.seed(333)
   expect_error(cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "shepherd"))
 })
 
 
 test_that("cor_test blomqvist", {
-  if (require("wdm", quietly = TRUE)) {
-    set.seed(333)
-    out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "blomqvist")
-    expect_equal(out$r, -0.4583333, tolerance = 0.01)
-  }
+  skip_if_not_or_load_if_installed("wdm")
+
+  set.seed(333)
+  out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "blomqvist")
+  expect_equal(out$r, -0.4583333, tolerance = 0.01)
 })
 
 test_that("cor_test hoeffding", {
-  if (require("Hmisc", quietly = TRUE)) {
-    set.seed(333)
-    out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "hoeffding")
-    expect_equal(out$r, 0.04427718, tolerance = 0.01)
-  }
+  skip_if_not_or_load_if_installed("Hmisc")
+
+  set.seed(333)
+  out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "hoeffding")
+  expect_equal(out$r, 0.04427718, tolerance = 0.01)
 })
 
 test_that("cor_test gamma", {
+  skip_if_not_or_load_if_installed("ggplot2")
+
   set.seed(333)
   out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "gamma")
   expect_equal(out$r, -0.2675799, tolerance = 0.01)
 })
 
 test_that("cor_test gaussian", {
+  skip_if_not_or_load_if_installed("ggplot2")
+
   set.seed(333)
   out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "gaussian")
   expect_equal(out$r, -0.3679795, tolerance = 0.01)
 
-  if (requireNamespace("BayesFactor")) {
-    out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "gaussian", bayesian = TRUE)
-    expect_equal(out$r, -0.3269572, tolerance = 0.01)
-  }
+  skip_if_not_or_load_if_installed("BayesFactor")
+  out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", method = "gaussian", bayesian = TRUE)
+  expect_equal(out$r, -0.3269572, tolerance = 0.01)
 })
 
 
@@ -123,6 +131,8 @@ test_that("cor_test gaussian", {
 
 
 test_that("cor_test one-sided p value", {
+  skip_if_not_or_load_if_installed("ggplot2")
+
   baseline <- cor.test(ggplot2::msleep$brainwt, ggplot2::msleep$sleep_rem, alternative = "greater")
 
   out <- cor_test(ggplot2::msleep, "brainwt", "sleep_rem", alternative = "greater")
