@@ -1,4 +1,3 @@
-
 test_that("cor_to_cov", {
   cor <- cor(iris[1:4])
   cov <- cov(iris[1:4])
@@ -23,7 +22,8 @@ test_that("z_fisher works", {
 })
 
 test_that("simulate_simpson works", {
+  skip_if_not_or_load_if_installed("MASS")
   set.seed(123)
-  df <- simulate_simpson(n = 100, groups = 5, r = 0.5)
+  df <- bayestestR::simulate_simpson(n = 100, groups = 5, r = 0.5)
   expect_equal(dim(df), c(500L, 3L))
 })
